==> IOFireWireFamily-121.4.2.tar.gz: IOFireWireFamily-121.4.2/IOFireWireFamily.kmodproj/IOFireWireBus.cpp <==
/*
 * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 * 
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1999-2002 Apple Computer, Inc.  All rights reserved.
 *
 * HISTORY
 * 27 April 99 wgulland created.
 *
 */

#include <IOKit/firewire/IOFireWireBus.h>

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

OSDefineMetaClass( IOFireWireBus, IOService )
OSDefineAbstractStructors(IOFireWireBus, IOService)
//OSMetaClassDefineReservedUnused(IOFireWireBus, 0);
//OSMetaClassDefineReservedUnused(IOFireWireBus, 1);
//OSMetaClassDefineReservedUnused(IOFireWireBus, 2);
OSMetaClassDefineReservedUnused(IOFireWireBus, 3);
OSMetaClassDefineReservedUnused(IOFireWireBus, 4);
OSMetaClassDefineReservedUnused(IOFireWireBus, 5);
OSMetaClassDefineReservedUnused(IOFireWireBus, 6);
OSMetaClassDefineReservedUnused(IOFireWireBus, 7);

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

==> IOFireWireFamily-121.4.3.tar.gz: IOFireWireFamily-120.4.3/IOFireWireFamily.kmodproj/IOFireWireBus.cpp <==
/*
 * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * The contents of this file constitute Original Code as defined in and
 * are subject to the Apple Public Source License Version 1.1 (the
 * "License").  You may not use this file except in compliance with the
 * License.  Please obtain a copy of the License at
 * http://www.apple.com/publicsource and read it before using this file.
 * 
 * This Original Code and all software distributed under the License are
 * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
 * License for the specific language governing rights and limitations
 * under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */
/*
 * Copyright (c) 1999-2002 Apple Computer, Inc.  All rights reserved.
 *
 * HISTORY
 * 27 April 99 wgulland created.
 *
 */

#include <IOKit/firewire/IOFireWireBus.h>

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

OSDefineMetaClass( IOFireWireBus, IOService )
OSDefineAbstractStructors(IOFireWireBus, IOService)
//OSMetaClassDefineReservedUnused(IOFireWireBus, 0);
//OSMetaClassDefineReservedUnused(IOFireWireBus, 1);
OSMetaClassDefineReservedUnused(IOFireWireBus, 2);
OSMetaClassDefineReservedUnused(IOFireWireBus, 3);
OSMetaClassDefineReservedUnused(IOFireWireBus, 4);
OSMetaClassDefineReservedUnused(IOFireWireBus, 5);
OSMetaClassDefineReservedUnused(IOFireWireBus, 6);
OSMetaClassDefineReservedUnused(IOFireWireBus, 7);

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
